# h5nav

[![Coverage
Status](https://coveralls.io/repos/github/clapeyre/h5nav/badge.svg?branch=master)](https://coveralls.io/github/clapeyre/h5nav?branch=master)
![python](https://img.shields.io/badge/python-2.7-blue.svg)
![release](https://img.shields.io/badge/release-v0.1.0-blue.svg)
[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/clapeyre)

Python tool for interactive navigation of an hdf5 file in a "unix shell"
fashion.

## Installation

Get the files:
```
git clone https://github.com/clapeyre/h5nav.git
```

and install using the make shortcut:

```
make install
```

or, if you prefer to get more control, use the usual python method,
*e.g.*:

```
python setup.py install --user
```

## Authors

* [**Corentin J. Lapeyre**](https://clapeyre.github.io/)
